
.. _gui:

GUI documentation
=================

Start with the `quick start tutorial <../quickstart.html>`__.

This part of the documentation contains a comprehensive description of all menus
and options to:

- `Load and view data <load.html>`__
- `Annotate song <annotate.html>`__
- `Train a network <train.html>`__
- `Generate annotations using the network <predict.html>`__


.. toctree::
   :maxdepth: 1
   :hidden:

   :toctree: GUI
   load
   annotate
   train
   predict
